import matplotlib.pyplot as plt
import pandas as pd


def plot_episode_stats(stats, smoothing_window=10, noshow=False):
    fig, axes = plt.subplots(1, 2, figsize=(10, 5), tight_layout=True)

    # Plot the episode length over time
    ax = axes[0]
    ax.plot(stats.episode_lengths)
    ax.set_xlabel("Episode")
    ax.set_ylabel("Episode Length")
    ax.set_title("Episode Length over Time")

    # Plot the episode reward over time
    ax = axes[1]
    rewards_smoothed = pd.Series(stats.episode_rewards).rolling(smoothing_window, min_periods=smoothing_window).mean()
    ax.plot(rewards_smoothed)
    ax.set_xlabel("Episode")
    ax.set_ylabel("Episode Reward (Smoothed)")
    ax.set_title("Episode Reward over Time\n(Smoothed over window size {})".format(smoothing_window))

    
def rendered_rollout(env, dqn, max_steps=200):
    done = False
    steps = 0

    state = env.reset()
    env.render()

    while not done and steps < max_steps:
        action = dqn.get_action(state, 0)
        state, _, done, _ = env.step(action)
        env.render()
        
        steps += 1
    env.close()